Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5703)

Unified Diff: chrome/common/chrome_notification_types.h

Issue 11824050: InstantExtended: Committed NTP (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/chrome_notification_types.h
diff --git a/chrome/common/chrome_notification_types.h b/chrome/common/chrome_notification_types.h
index 50784b6b4932523348e48c025c62127f5228ee53..1e30cffdb5cb49c150090a0b60d6f1e1f50eba1a 100644
--- a/chrome/common/chrome_notification_types.h
+++ b/chrome/common/chrome_notification_types.h
@@ -1101,9 +1101,13 @@ enum NotificationType {
// containing the committed preview.
NOTIFICATION_INSTANT_COMMITTED,
- // Sent when the Instant loader determines whether the page supports the
+ // Sent when the Instant Controller determines whether the overlay supports
+ // the Instant API or not.
+ NOTIFICATION_INSTANT_OVERLAY_SUPPORT_DETERMINED,
+
+ // Sent when the Instant Controller determines whether the ntp supports the
sreeram 2013/02/07 21:17:50 ntp -> NTP
samarth 2013/02/07 22:11:55 Done.
// Instant API or not.
- NOTIFICATION_INSTANT_SUPPORT_DETERMINED,
+ NOTIFICATION_INSTANT_NTP_SUPPORT_DETERMINED,
// Sent when the CaptivePortalService checks if we're behind a captive portal.
// The Source is the Profile the CaptivePortalService belongs to, and the

Powered by Google App Engine
This is Rietveld 408576698